==> ejc-doc-api-3.0.0-20210222.045202-54-sources.jar: com/ejianc/business/doc/vo/KbmVO.java <==
package com.ejianc.business.doc.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 知识内容
 *
 * @author generator
 *
 */
public class KbmVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId; // 文档贡献组织Id
    private String orgName; // 文档贡献组织名称
    private Long categoryId; // 分类Id
    private String categoryName; // 分类名称
    private String title; // 标题
    private String kbmDescribe; // 描述说明
    private String source; // 文件来源：0-企业文件，1-个人上传
    private java.math.BigDecimal scanNum; // 浏览量
    private java.math.BigDecimal collectNum; // 收藏量
    private Integer billState; // 单据状态0-暂存，1-已发布
    private String categoryInnerCode; // 分类内部编码
    private java.math.BigDecimal fileNum; // 附件数
    private String fileName; //附件名称（逗号隔开）
    private String createUserName; //创建人名称
    private Integer collectState;//收藏状态0-未收藏，1-已收藏
    private Long createUserId; // 创建人ID

    /**
     * 文档贡献组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 文档贡献组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 文档贡献组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 文档贡献组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 分类Id
     */
    public Long getCategoryId() {
        return categoryId;
    }

    /**
     * 分类Id
     */
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    /**
     * 分类名称
     */
    public String getCategoryName() {
        return categoryName;
    }

    /**
     * 分类名称
     */
    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    /**
     * 标题
     */
    public String getTitle() {
        return title;
    }

    /**
     * 标题
     */
    public void setTitle(String title) {
        this.title = title;
    }
    /**
     * 描述说明
     */
    public String getKbmDescribe() {
        return kbmDescribe;
    }

    /**
     * 描述说明
     */
    public void setKbmDescribe(String kbmDescribe) {
        this.kbmDescribe = kbmDescribe;
    }
    /**
     * 文件来源：0-企业文件，1-个人上传
     */
    public String getSource() {
        return source;
    }

    /**
     * 文件来源：0-企业文件，1-个人上传
     */
    public void setSource(String source) {
        this.source = source;
    }
    /**
     * 浏览量
     */
    public java.math.BigDecimal getScanNum() {
        return scanNum;
    }

    /**
     * 浏览量
     */
    public void setScanNum(java.math.BigDecimal scanNum) {
        this.scanNum = scanNum;
    }
    /**
     * 收藏量
     */
    public java.math.BigDecimal getCollectNum() {
        return collectNum;
    }

    /**
     * 收藏量
     */
    public void setCollectNum(java.math.BigDecimal collectNum) {
        this.collectNum = collectNum;
    }
    /**
     * 单据状态0-暂存，1-已发布
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态0-暂存，1-已发布
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 分类内部编码
     */
    public String getCategoryInnerCode() {
        return categoryInnerCode;
    }

    /**
     * 分类内部编码
     */
    public void setCategoryInnerCode(String categoryInnerCode) {
        this.categoryInnerCode = categoryInnerCode;
    }
    /**
     * 附件数
     */
    public java.math.BigDecimal getFileNum() {
        return fileNum;
    }

    /**
     * 附件数
     */
    public void setFileNum(java.math.BigDecimal fileNum) {
        this.fileNum = fileNum;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Integer getCollectState() {
        return collectState;
    }

    public void setCollectState(Integer collectState) {
        this.collectState = collectState;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
}

==> ejc-doc-api-3.0.0-20230527.054056-112-sources.jar: com/ejianc/business/doc/vo/KbmVO.java <==
package com.ejianc.business.doc.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 知识内容
 *
 * @author generator
 *
 */
public class KbmVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long orgId; // 文档贡献组织Id
    private String orgName; // 文档贡献组织名称
    private Long categoryId; // 分类Id
    private String categoryName; // 分类名称
    private String title; // 标题
    private String kbmDescribe; // 描述说明
    private String sourceType; // 文件来源：0-企业文件，1-个人上传
    private java.math.BigDecimal scanNum; // 浏览量
    private java.math.BigDecimal collectNum; // 收藏量
    private Integer billState; // 单据状态0-暂存，1-已发布
    private String categoryInnerCode; // 分类内部编码
    private java.math.BigDecimal fileNum; // 附件数
    private String fileName; //附件名称（逗号隔开）
    private String createUserName; //创建人名称
    private Integer collectState;//收藏状态0-未收藏，1-已收藏
    private Long createUserId; // 创建人ID

    /**
     * 文档贡献组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 文档贡献组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 文档贡献组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 文档贡献组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 分类Id
     */
    public Long getCategoryId() {
        return categoryId;
    }

    /**
     * 分类Id
     */
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    /**
     * 分类名称
     */
    public String getCategoryName() {
        return categoryName;
    }

    /**
     * 分类名称
     */
    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    /**
     * 标题
     */
    public String getTitle() {
        return title;
    }

    /**
     * 标题
     */
    public void setTitle(String title) {
        this.title = title;
    }
    /**
     * 描述说明
     */
    public String getKbmDescribe() {
        return kbmDescribe;
    }

    /**
     * 描述说明
     */
    public void setKbmDescribe(String kbmDescribe) {
        this.kbmDescribe = kbmDescribe;
    }
    /**
     * 文件来源：0-企业文件，1-个人上传
     */
    public String getSourceType() {
        return sourceType;
    }

    /**
     * 文件来源：0-企业文件，1-个人上传
     */
    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    /**
     * 浏览量
     */
    public java.math.BigDecimal getScanNum() {
        return scanNum;
    }

    /**
     * 浏览量
     */
    public void setScanNum(java.math.BigDecimal scanNum) {
        this.scanNum = scanNum;
    }
    /**
     * 收藏量
     */
    public java.math.BigDecimal getCollectNum() {
        return collectNum;
    }

    /**
     * 收藏量
     */
    public void setCollectNum(java.math.BigDecimal collectNum) {
        this.collectNum = collectNum;
    }
    /**
     * 单据状态0-暂存，1-已发布
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态0-暂存，1-已发布
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 分类内部编码
     */
    public String getCategoryInnerCode() {
        return categoryInnerCode;
    }

    /**
     * 分类内部编码
     */
    public void setCategoryInnerCode(String categoryInnerCode) {
        this.categoryInnerCode = categoryInnerCode;
    }
    /**
     * 附件数
     */
    public java.math.BigDecimal getFileNum() {
        return fileNum;
    }

    /**
     * 附件数
     */
    public void setFileNum(java.math.BigDecimal fileNum) {
        this.fileNum = fileNum;
    }

    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Integer getCollectState() {
        return collectState;
    }

    public void setCollectState(Integer collectState) {
        this.collectState = collectState;
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }
}
